@@ -13,7 +13,7 @@ import threading
 import time
 import typing
 import urllib.parse
-from typing import Optional, Callable, Type, Literal
+from typing import Callable, Literal, Optional, Type
 
 from loguru import logger
 
@@ -278,6 +278,7 @@ class ClashProxy(BaseProxy):
         if not key.startswith("http" + "://"):
             key = "http" + "://" + key
         if match is ...:
+
             def match(x):
                 return str(x) not in ["DIRECT", "REJECT"]
 
@@ -317,7 +318,7 @@ class ClashProxy(BaseProxy):
             now = resp.get(f"proxies.{self.selector}.now")
             nodes = resp.get(f"proxies.{self.selector}.all")
             if now in nodes:
-                nodes = [*nodes[nodes.index(now) + 1 :], *nodes[: nodes.index(now) + 1]]
+                nodes = [*nodes[nodes.index(now) + 1:], *nodes[: nodes.index(now) + 1]]
             self._nodes = self.iter_node(list(filter(self.match, nodes)))
             return nodes
         else:
