@@ -10,7 +10,7 @@ import time
 from loguru import logger
 
 from bricks import state
-from bricks.db.redis_ import Redis, LUA
+from bricks.db.redis_ import LUA, Redis
 from bricks.lib.queues import TaskQueue
 from bricks.utils import pandora
 
@@ -18,14 +18,17 @@ from bricks.utils import pandora
 class RedisQueue(TaskQueue):
     subscribe = True
 
-    def __init__(self, host='127.0.0.1', password=None, port=6379, database=0, genre="set", **kwargs):
-
+    def __init__(
+            self,
+            host="127.0.0.1",
+            password=None,
+            port=6379,
+            database=0,
+            genre="set",
+            **kwargs,
+    ):
         self.redis_db = Redis(
-            host=host,
-            password=password,
-            port=port,
-            database=database,
-            **kwargs
+            host=host, password=password, port=port, database=database, **kwargs
         )
         self.host = host
         self.database = database
@@ -167,14 +170,13 @@ class RedisQueue(TaskQueue):
         status = redis.call("HGET", record_key, "status")
     end
 
-    if status != '1' and queue_size > 0 then
+    if status ~= '1' and queue_size > 0 then
         return "已投完且存在种子没有消费完毕"
         
     else
         -- 先拿锁, 拿不到了就返回没有权限
         local ok = redis.call("SETNX", heartbeat_key, date_str)
-        if(ok != 1)
-        then
+        if ok ~= 1 then
            return "获取心跳锁失败"
         end
         -- 拿到了锁
@@ -191,6 +193,7 @@ class RedisQueue(TaskQueue):
     local ttl = KEYS[5]
     changeDataBase(db_num)
     redis.call("HSET", record_key, "status", 0)
+    redis.call("HSET", record_key, "stop_heartbeat", 1)
     if ttl ~= 0 then
         redis.call("DEL", history_key)
         local dump = redis.call('DUMP', record_key)
@@ -199,6 +202,19 @@ class RedisQueue(TaskQueue):
     return true
                     """)
 
+            continue_init_heartbeat = self.lua.register("""
+    local record_key = KEYS[1]
+    local heartbeat_key = KEYS[2]
+    local interval = KEYS[3]
+    local stop_heartbeat = redis.call("HGET", record_key, "stop_heartbeat")
+    if stop_heartbeat == "1" then
+        redis.call("HDEL", record_key, "stop_heartbeat")
+        return false
+    end
+    redis.call("SETEX", heartbeat_key, interval, redis.call("TIME")[1])
+    return true
+            """)
+
         self.scripts = Scripts
 
     def get(self, name, count: int = 1, **kwargs):
@@ -211,10 +227,10 @@ class RedisQueue(TaskQueue):
         :return:
         """
 
-        pop_key = self.name2key(name, 'current')
-        add_key = self.name2key(name, 'temp')
-        db_num = kwargs.get('db_num', self.database)
-        genre = kwargs.get('genre', self.genre)
+        pop_key = self.name2key(name, "current")
+        add_key = self.name2key(name, "temp")
+        db_num = kwargs.get("db_num", self.database)
+        genre = kwargs.get("genre", self.genre)
         keys = [db_num, pop_key, count or 1, genre, add_key]
         return self.scripts.get(keys=keys)
 
@@ -227,15 +243,19 @@ class RedisQueue(TaskQueue):
         :param kwargs:
         :return:
         """
-        db_num = kwargs.get('db_num', self.database)
-        genre = kwargs.get('genre', self.genre)
-        qtypes = kwargs.get('qtypes', ["current"])
+        db_num = kwargs.get("db_num", self.database)
+        genre = kwargs.get("genre", self.genre)
+        qtypes = kwargs.get("qtypes", ["current"])
 
         if not name or not values:
             return 0
 
         values = self.py2str(*values)
-        keys = [db_num, genre, *[self.name2key(name, qtype) for qtype in pandora.iterable(qtypes)]]
+        keys = [
+            db_num,
+            genre,
+            *[self.name2key(name, qtype) for qtype in pandora.iterable(qtypes)],
+        ]
         args = [*values]
         count = self.scripts.put(keys=keys, args=args)
         return count
@@ -252,11 +272,15 @@ class RedisQueue(TaskQueue):
         if not name or not values:
             return 0
 
-        db_num = kwargs.get('db_num', self.database)
-        genre = kwargs.get('genre', self.genre)
-        qtypes = kwargs.get('qtypes', ["current", "temp", "failure"])
+        db_num = kwargs.get("db_num", self.database)
+        genre = kwargs.get("genre", self.genre)
+        qtypes = kwargs.get("qtypes", ["current", "temp", "failure"])
 
-        keys = [db_num, genre, *[self.name2key(name, qtype) for qtype in pandora.iterable(qtypes)]]
+        keys = [
+            db_num,
+            genre,
+            *[self.name2key(name, qtype) for qtype in pandora.iterable(qtypes)],
+        ]
         args = [j for i in values for j in self.py2str(*i)]
         return self.scripts.replace(keys=keys, args=args)
 
@@ -271,24 +295,35 @@ class RedisQueue(TaskQueue):
         if not name or not values:
             return 0
 
-        backup = kwargs.get('backup', "")
-        if backup: 
+        backup = kwargs.get("backup", "")
+        if backup:
             backup = self.name2key(name, backup)
-            
-        db_num = kwargs.get('db_num', self.database)
-        genre = kwargs.get('genre', self.genre)
-        qtypes = kwargs.get('qtypes', ["temp"])
-        keys = [db_num, genre, backup, *[self.name2key(name, qtype) for qtype in pandora.iterable(qtypes)]]
+
+        db_num = kwargs.get("db_num", self.database)
+        genre = kwargs.get("genre", self.genre)
+        qtypes = kwargs.get("qtypes", ["temp"])
+        keys = [
+            db_num,
+            genre,
+            backup,
+            *[self.name2key(name, qtype) for qtype in pandora.iterable(qtypes)],
+        ]
         args = self.py2str(*values)
         return self.scripts.remove(keys=keys, args=args)
 
-    def clear(self, *names, qtypes=('current', 'temp', "lock", "record", "failure"), **kwargs):
-        db_num = kwargs.pop('db_num', self.database)
+    def clear(
+            self, *names, qtypes=("current", "temp", "lock", "record", "failure"), **kwargs
+    ):
+        db_num = kwargs.pop("db_num", self.database)
         keys = [db_num]
-        args = [self.name2key(name, qtype) for name in names for qtype in pandora.iterable(qtypes)]
+        args = [
+            self.name2key(name, qtype)
+            for name in names
+            for qtype in pandora.iterable(qtypes)
+        ]
         return self.scripts.delete(keys=keys, args=args)
 
-    def size(self, *names, qtypes=('current', 'temp', "failure"), **kwargs):
+    def size(self, *names, qtypes=("current", "temp", "failure"), **kwargs):
         """
         获取 `names` 的队列大小
 
@@ -299,10 +334,12 @@ class RedisQueue(TaskQueue):
         if not names:
             return 0
 
-        db_num = kwargs.pop('db_num', self.database)
-        genre = kwargs.get('genre', self.genre)
+        db_num = kwargs.pop("db_num", self.database)
+        genre = kwargs.get("genre", self.genre)
         keys = [db_num, genre]
-        args = [self.name2key(name, _) for name in names for _ in pandora.iterable(qtypes)]
+        args = [
+            self.name2key(name, _) for name in names for _ in pandora.iterable(qtypes)
+        ]
         return self.scripts.count(keys=keys, args=args)
 
     def reverse(self, name, **kwargs):
@@ -315,10 +352,10 @@ class RedisQueue(TaskQueue):
         if not name:
             return 0
 
-        db_num = kwargs.pop('db_num', self.database)
-        qtypes = kwargs.pop('qtypes', ["temp", "failure"])
-        genre = kwargs.get('genre', self.genre)
-        dest = self.name2key(name, 'current')
+        db_num = kwargs.pop("db_num", self.database)
+        qtypes = kwargs.pop("qtypes", ["temp", "failure"])
+        genre = kwargs.get("genre", self.genre)
+        dest = self.name2key(name, "current")
         args = [self.name2key(name, qtype) for qtype in pandora.iterable(qtypes)]
         return self.merge(dest, *args, db_num=db_num, genre=genre)
 
@@ -333,8 +370,8 @@ class RedisQueue(TaskQueue):
         if not dest or not queues:
             return 0
 
-        db_num = kwargs.pop('db_num', self.database)
-        genre = kwargs.get('genre', self.genre)
+        db_num = kwargs.pop("db_num", self.database)
+        genre = kwargs.get("genre", self.genre)
         keys = [db_num, genre, dest]
         args = queues
         return self.scripts.reverse(keys=keys, args=args)
@@ -353,17 +390,21 @@ class RedisQueue(TaskQueue):
 
         # 告诉其他机器开始上报状态
         self.publish(
-            chanel=f'{name}-subscribe',
-            msg={
-                "action": "collect-status",
-                "key": self.name2key(name, "report")
-            },
-            timeout=timeout
+            chanel=f"{name}-subscribe",
+            msg={"action": "collect-status", "key": self.name2key(name, "report")},
+            timeout=timeout,
         )
 
-        db_num = kwargs.pop('db_num', self.database)
-        genre = kwargs.get('genre', self.genre)
-        keys = [db_num, genre, *[self.name2key(name, qtype) for qtype in ["current", "temp", "failure", "report"]]]
+        db_num = kwargs.pop("db_num", self.database)
+        genre = kwargs.get("genre", self.genre)
+        keys = [
+            db_num,
+            genre,
+            *[
+                self.name2key(name, qtype)
+                for qtype in ["current", "temp", "failure", "report"]
+            ],
+        ]
         ret = self.scripts.smart_reverse(keys=keys)
         return ret == 1
 
@@ -387,25 +428,24 @@ class RedisQueue(TaskQueue):
     def from_redis(cls, obj, **kwargs):
         connection_kwargs: dict = obj.connection_pool.connection_kwargs
         params = dict(
-            host=connection_kwargs.get('host', '127.0.0.1'),
-            password=connection_kwargs.get('password'),
-            port=connection_kwargs.get('port', 6379),
-            database=connection_kwargs.get('db', 0),
+            host=connection_kwargs.get("host", "127.0.0.1"),
+            password=connection_kwargs.get("password"),
+            port=connection_kwargs.get("port", 6379),
+            database=connection_kwargs.get("db", 0),
         )
         params.update(**kwargs)
         return cls(**params)
 
     def command(self, name: str, order: dict):
-
         def run_subscribe(chanel, adapters: dict):
             """
             订阅消息
             """
 
             def main(message):
-                msg: dict = json.loads(message['data'])
-                _action = msg['action']
-                recv: str = msg.get('recv', state.MACHINE_ID)
+                msg: dict = json.loads(message["data"])
+                _action = msg["action"]
+                recv: str = msg.get("recv", state.MACHINE_ID)
                 if recv != state.MACHINE_ID:
                     return
 
@@ -437,79 +477,83 @@ class RedisQueue(TaskQueue):
             """
 
             def heartbeat():
+                _keys = [
+                    self.name2key(name, "record"),
+                    heartbeat_key,
+                    interval
+                ]
                 while True:
                     try:
-                        self.redis_db.setex(heartbeat_key, interval, str(datetime.datetime.now()))
+                        if not self.scripts.continue_init_heartbeat(keys=_keys):
+                            break
                         time.sleep(interval - 1)
                     except (KeyboardInterrupt, SystemExit):
                         raise
 
                     except Exception as e:
-                        logger.error(f"[get_permission] {e}")
+                        logger.error(f"[heartbeat] {e}")
                         time.sleep(1)
 
-            db_num = order.get('db_num', self.database)
-            genre = order.get('genre', self.genre)
+            db_num = order.get("db_num", self.database)
+            genre = order.get("genre", self.genre)
             interval = order.get("interval", 5)
 
             heartbeat_key = self.name2key(name, "heartbeat")
             keys = [
                 db_num,
-                *[self.name2key(name, i) for i in ['current', 'temp', 'failure', 'record']],
+                *[
+                    self.name2key(name, i)
+                    for i in ["current", "temp", "failure", "record"]
+                ],
                 heartbeat_key,
                 str(datetime.datetime.now()),
                 interval,
-                genre
+                genre,
             ]
 
             while True:
-                msg = self.scripts.get_permission(keys=keys)
-                start_time = time.time()
+                try:
+                    msg = self.scripts.get_permission(keys=keys)
+                    start_time = time.time()
 
-                if msg == "成功获取权限":
-                    # 拿到了权限, 开启心跳任务, 去更新 heartbeat 锁的时间
-                    threading.Thread(target=heartbeat, daemon=True).start()
-                    return {
-                        "state": True,
-                        "msg": msg
-                    }
+                    if msg == "成功获取权限":
+                        # 拿到了权限, 开启心跳任务, 去更新 heartbeat 锁的时间
+                        threading.Thread(target=heartbeat, daemon=True).start()
+                        return {"state": True, "msg": msg}
 
-                elif msg == "已投完且存在种子没有消费完毕":
-                    return {
-                        "state": False,
-                        "msg": msg
-                    }
+                    elif msg == "已投完且存在种子没有消费完毕":
+                        return {"state": False, "msg": msg}
 
-                else:  # 获取心跳锁失败
-                    last = ""
-                    while time.time() - start_time < interval * 3:  # 判断 interval*3 秒
-                        heartbeat_value = self.redis_db.get(heartbeat_key)
-                        # 锁变为空了, 重新开始所有流程
-                        if heartbeat_value == "":
-                            break
+                    else:  # 获取心跳锁失败
+                        last = ""
+                        while time.time() - start_time < interval * 3:  # 判断 interval*3 秒
+                            heartbeat_value = self.redis_db.get(heartbeat_key)
+                            # 锁变为空了, 重新开始所有流程
+                            if heartbeat_value == "":
+                                break
 
-                        # 锁的内容在变化, 有人在操作, 直接返回
-                        if last and last != heartbeat_value:  # 只要在变化, 就不嘻嘻
-                            return {
-                                "state": False,
-                                "msg": "存在其他活跃的初始化机器"
-                            }
+                            # 锁的内容在变化, 有人在操作, 直接返回
+                            if last and last != heartbeat_value:  # 只要在变化, 就不嘻嘻
+                                return {"state": False, "msg": "存在其他活跃的初始化机器"}
 
-                        last = heartbeat_value
-                        time.sleep(1)
+                            last = heartbeat_value
+                            time.sleep(1)
 
-                    # 锁没动过, 也重新开始所有流程
+                        # 锁没动过, 也重新开始所有流程
+                except Exception as permission_e:
+                    logger.error(f"[get_permission] {permission_e}")
+                    time.sleep(30)
 
         def set_record():
             self.redis_db.hset(
-                self.name2key(name, 'record'),
-                mapping=json.loads(json.dumps(order['record'], default=str))
+                self.name2key(name, "record"),
+                mapping=json.loads(json.dumps(order["record"], default=str)),
             )
 
         def wait_init():
-            key = self.name2key(name, 'record')
+            key = self.name2key(name, "record")
             # 爬虫的启动时间
-            t1 = order.get('time')
+            t1 = order.get("time")
 
             while True:
                 # 如果队列不为空 -> 不需要等待初始化
@@ -527,71 +571,72 @@ class RedisQueue(TaskQueue):
                 if t2 and float(t2) >= t1:
                     return
 
-                logger.debug('等待初始化开始')
+                logger.debug("等待初始化开始")
                 time.sleep(1)
 
         def set_init():
             key = self.name2key(name, "record")
-            self.redis_db.hset(key, mapping={
-                "time": int(time.time() * 1000),
-                "status": 1
-            })
+            self.redis_db.hset(
+                key, mapping={"time": int(time.time() * 1000), "status": 1}
+            )
 
         def is_init():
-            key = self.name2key(name, 'record')
+            key = self.name2key(name, "record")
             # 队列不为空 -> true
             if not self.is_empty(name):
                 return True
 
             # record 存在, 并且 status 为 1 -> true
-            if self.redis_db.exists(key) and self.redis_db.hget(key, 'status') == "1":
+            if self.redis_db.exists(key) and self.redis_db.hget(key, "status") == "1":
                 return True
 
             return False
 
         def release_init():
             key = self.name2key(name, "record")
-            history = self.name2key(name, 'history')
-            db_num = order.get('db_num', self.database)
-            ttl = order.get('ttl') or 0
+            history = self.name2key(name, "history")
+            db_num = order.get("db_num", self.database)
+            ttl = order.get("ttl") or 0
 
-            ret = self.scripts.release_init(keys=[key, history, db_num, state.MACHINE_ID, ttl])
+            ret = self.scripts.release_init(
+                keys=[key, history, db_num, state.MACHINE_ID, ttl]
+            )
             return bool(ret)
 
         def get_record():
-            key = self.name2key(name, 'record')
+            key = self.name2key(name, "record")
             record = self.redis_db.hgetall(key) or {}
-            if record.get('status') == "0":
+            if record.get("status") == "0":
                 self.redis_db.delete(key)
                 return {}
             else:
                 return record
 
         actions = {
-            self.COMMANDS.RUN_SUBSCRIBE: lambda: run_subscribe(f'{name}-subscribe', order['target']),
+            self.COMMANDS.RUN_SUBSCRIBE: lambda: run_subscribe(
+                f"{name}-subscribe", order["target"]
+            ),
             self.COMMANDS.GET_PERMISSION: get_permission,
-
             self.COMMANDS.GET_RECORD: get_record,
             self.COMMANDS.CONTINUE_RECORD: lambda: self.reverse(name),
             self.COMMANDS.SET_RECORD: set_record,
-
             self.COMMANDS.WAIT_INIT: wait_init,
             self.COMMANDS.RESET_INIT: lambda: self.clear(name),
             self.COMMANDS.RELEASE_INIT: release_init,
             self.COMMANDS.IS_INIT: is_init,
             self.COMMANDS.SET_INIT: set_init,
         }
-        action = order['action']
+        action = order["action"]
         if action in actions:
             return actions[action]()
 
     def __str__(self):
-        return f'<RedisQueue [ HOST: {self.host} | DB: {self.database} ]>'
+        return f"<RedisQueue [ HOST: {self.host} | DB: {self.database} ]>"
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     q = RedisQueue(genre="zset")
-    print(q.put('xxx', 'dasdasd4564646'))
+    print(q.put("xxx", "dasdasd4564646"))
     # print(q.replace('xxx', ({"name": "kemxxxx"}, {"name": "kem"})))
     # print(q.remove('xxx', *({"name": "kem"}, {"name": "xxx"}), qtypes=["current"]))
     # print(q.clear('xxx'))
