@@ -37,17 +37,22 @@ _fetchers_cache = {}
 
 class Context(Flow):
     def __init__(
-        self,
-        target: "Spider",
-        form: str = state.const.ON_CONSUME,
-        division: Optional[bool] = False,
-        **kwargs,
+            self,
+            target: "Spider",
+            form: str = state.const.ON_CONSUME,
+            division: bool = False,
+            request: Request = None,
+            response: Response = None,
+            seeds: Item = None,
+            items: Items = None,
+            task_queue: TaskQueue = None,
+            **kwargs,
     ) -> None:
-        self.request: Optional[Request] = kwargs.pop("request", None)
-        self.response: Optional[Response] = kwargs.pop("response", None)
-        self.seeds: Optional[Union[Item, List[Item]]] = kwargs.pop("seeds", None)
-        self.items: Optional[Items] = kwargs.pop("items", None)
-        self.task_queue: Optional[TaskQueue] = kwargs.pop("task_queue", None)
+        self.request: Request = request
+        self.response: Response = response
+        self.seeds: Item = seeds
+        self.items: Items = items
+        self.task_queue: TaskQueue = task_queue
         self.queue_name: str = kwargs.pop(
             "queue_name", f"{self.__class__.__module__}.{self.__class__.__name__}"
         )
@@ -69,7 +74,7 @@ class Context(Flow):
 
     def success(self, shutdown=False):
         ret = self.task_queue.remove(self.queue_name, *pandora.iterable(self.seeds))
-        shutdown and self.flow({"next": None})
+        shutdown and self.flow({"next": None})  # type: ignore
         return ret
 
     def retry(self):
@@ -82,7 +87,7 @@ class Context(Flow):
             )
         else:
             ret = 0
-        shutdown and self.flow({"next": None})
+        shutdown and self.flow({"next": None})  # type: ignore
         return ret
 
     def replace(self, new: dict, qtypes=("current", "temp", "failure")):
@@ -92,7 +97,7 @@ class Context(Flow):
         :return:
         """
         ret = self.task_queue.replace(self.queue_name, (self.seeds, new), qtypes=qtypes)
-        self.seeds = new
+        self.seeds = new  # type: ignore
         return ret
 
     def save(self):
@@ -101,11 +106,11 @@ class Context(Flow):
     def divisive(self, qtypes=("temp",)):
         new = {**self.seeds, "$division": str(uuid.uuid4())}
         self.task_queue.put(self.queue_name, new, qtypes=qtypes)
-        self.seeds = new
+        self.seeds = new  # type: ignore
         return new
 
     def submit(
-        self, *obj: Union[Item, dict], call_later=False, attrs: dict = None
+            self, *obj: Union[Item, dict], call_later=False, attrs: Optional[dict] = None
     ) -> List["Context"]:
         """
         专门为新请求分支封装的方法, 会自动将请求放入队列
@@ -133,7 +138,7 @@ class Context(Flow):
                 qtypes = "temp"
 
             self.target.put_seeds(
-                obj,
+                obj,  # type: ignore
                 task_queue=self.task_queue,
                 queue_name=self.queue_name,
                 qtypes=qtypes,
@@ -151,15 +156,20 @@ class Context(Flow):
 
 class InitContext(Flow):
     def __init__(
-        self, target: "Spider", form: str = state.const.ON_INIT, **kwargs
+            self, target: "Spider", form: str = state.const.ON_INIT,
+            seeds: List[Item] = None,
+            task_queue: TaskQueue = None,
+            maxsize: int = None,
+            priority: bool = False,
+            **kwargs
     ) -> None:
-        self.seeds: Optional[List[Item]] = kwargs.pop("seeds", None)
-        self.task_queue: Optional[TaskQueue] = kwargs.pop("task_queue", None)
+        self.seeds: List[Item] = seeds
+        self.task_queue: TaskQueue = task_queue
         self.queue_name: str = kwargs.pop(
             "queue_name", f"{self.__class__.__module__}.{self.__class__.__name__}"
         )
-        self.maxsize: Optional[int] = kwargs.pop("maxsize", None)
-        self.priority: bool = kwargs.pop("priority", False)
+        self.maxsize: int = maxsize
+        self.priority: bool = priority
         super().__init__(form, target, **kwargs)
         self.target: Spider = target
 
@@ -167,22 +177,22 @@ class InitContext(Flow):
         if self.form == state.const.AFTER_PUT_SEEDS:
             self.task_queue.remove(self.queue_name, self.seeds)
 
-        shutdown and self.flow({"next": None})
+        shutdown and self.flow({"next": None})  # type: ignore
 
     def failure(self, shutdown=False):
         # 在种子投放之后, 如果收到失败信息, 就将种子移动至 failure 队列
         if self.form == state.const.AFTER_PUT_SEEDS:
             self.seeds and self.task_queue.remove(
                 self.queue_name, self.seeds, backup="failure"
-            )
+            )  # type: ignore
 
-        shutdown and self.flow({"next": None})
+        shutdown and self.flow({"next": None})  # type: ignore
 
     def retry(self):
         pass
 
-    def error(self, shutdown=False):
-        shutdown and self.flow({"next": None})
+    def error(self, e: Exception, shutdown=False):
+        shutdown and self.flow({"next": None})  # type: ignore
 
 
 class Spider(Pangu):
@@ -195,11 +205,11 @@ class Spider(Pangu):
             "downloader", cffi.Downloader()
         )
         self.task_queue: Optional[TaskQueue] = (
-            kwargs.pop("task_queue", LocalQueue()) or LocalQueue()
+                kwargs.pop("task_queue", LocalQueue()) or LocalQueue()
         )
         self.queue_name: Optional[str] = (
-            kwargs.pop("queue_name", "")
-            or f"{self.__class__.__module__}.{self.__class__.__name__}"
+                kwargs.pop("queue_name", "")
+                or f"{self.__class__.__module__}.{self.__class__.__name__}"
         )
         self.proxy: Optional[
             Union[dict, BaseProxy, str, List[Union[dict, BaseProxy, str]]]
@@ -238,8 +248,8 @@ class Spider(Pangu):
         :return:
         """
 
-        task_queue: TaskQueue = self.get("init.task_queue", self.task_queue)
-        queue_name: str = self.get("init.queue_name", self.queue_name)
+        task_queue: TaskQueue = self.get("init.task_queue", self.task_queue)  # type: ignore
+        queue_name: str = self.get("init.queue_name", self.queue_name)  # type: ignore
         # 判断是否有初始化权限
         permission_info: dict = task_queue.command(
             queue_name, {"action": task_queue.COMMANDS.GET_PERMISSION, "interval": 10}
@@ -260,10 +270,10 @@ class Spider(Pangu):
         local_init_record: dict = self.get("init.record") or {}
         # 云端的初始化记录 -> 初始化的时候会存储(如果支持的话)
         remote_init_record = (
-            task_queue.command(
-                queue_name, {"action": task_queue.COMMANDS.GET_RECORD, "filter": 1}
-            )
-            or {}
+                task_queue.command(
+                    queue_name, {"action": task_queue.COMMANDS.GET_RECORD, "filter": 1}
+                )
+                or {}
         )
 
         # 初始化记录信息
@@ -290,7 +300,8 @@ class Spider(Pangu):
         # 初始化成功数量阈值 (去重) -> 大于这个数量停止初始化
         success_size = self.get("init.success.size", math.inf)
         # 初始化队列最大数量 -> 大于这个数量暂停初始化
-        queue_size: int = self.get("init.queue.size", 100000)
+        queue_size: int = self.get("init.queue.size", 100000)  # type: ignore
+        is_continue: bool = self.get("init.continue", False)  # type: ignore
 
         settings = {
             "total": total,
@@ -304,12 +315,12 @@ class Spider(Pangu):
         }
 
         context = self.make_context(
+            self.InitContext,
             task_queue=task_queue,
             queue_name=queue_name,
-            _Context=self.InitContext,
             settings=settings,
         )
-        record: dict = settings.get("record") or {}
+        record: dict = settings.get("record") or {}  # type: ignore
 
         gen = pandora.invoke(
             func=self.make_seeds,
@@ -321,8 +332,18 @@ class Spider(Pangu):
         if not inspect.isgenerator(gen):
             gen = [gen]
 
+        need_skip = min(success, total)
         for seeds in gen:
-            ctx: InitContext = context.copy()
+            if is_continue and need_skip > 0:
+                seeds = pandora.iterable(seeds)
+                raw_size = len(seeds)
+                seeds = seeds[need_skip:]
+                need_skip -= raw_size - len(seeds)
+
+            if not seeds:
+                continue
+
+            ctx = context.copy()
             ctx.flow({"next": self.produce_seeds, "seeds": seeds})
             self.on_consume(ctx)
 
@@ -343,21 +364,21 @@ class Spider(Pangu):
         :param context:
         :return:
         """
-        settings: dict = context.obtain("settings")
+        settings: dict = context.obtain("settings") or {}
 
         seeds = context.seeds
         seeds = pandora.iterable(seeds)
 
         seeds = seeds[
-            0 : min(
-                [
-                    settings["count_size"] - settings["count"],
-                    settings["total_size"] - settings["total"],
-                    settings["success_size"] - settings["success"],
-                    len(seeds),
+                0: min(
+                    [
+                        settings["count_size"] - settings["count"],
+                        settings["total_size"] - settings["total"],
+                        settings["success_size"] - settings["success"],
+                        len(seeds),
+                    ]
+                )
                 ]
-            )
-        ]
         context.update(
             {
                 "maxsize": settings["queue_size"],
@@ -396,22 +417,22 @@ class Spider(Pangu):
         logger.debug(output)
 
         if (
-            settings["total"] >= settings["total_size"]
-            or settings["count"] >= settings["count_size"]
-            or settings["success"] >= settings["success_size"]
+                settings["total"] >= settings["total_size"]
+                or settings["count"] >= settings["count_size"]
+                or settings["success"] >= settings["success_size"]
         ):
             raise signals.Exit
         else:
             context.flow()
 
     def put_seeds(
-        self,
-        seeds: Union[dict, Item, Iterable[Item], Iterable[dict]],
-        task_queue: Optional[TaskQueue] = ...,
-        queue_name: Optional[str] = ...,
-        maxsize: Optional[int] = None,
-        priority: Optional[bool] = False,
-        **kwargs,
+            self,
+            seeds: Union[dict, Item, Iterable[Item], Iterable[dict]],
+            task_queue: Optional[TaskQueue] = ...,
+            queue_name: Optional[str] = ...,
+            maxsize: Optional[int] = None,
+            priority: Optional[bool] = False,
+            **kwargs,
     ):
         """
         将种子放入容器
@@ -430,24 +451,27 @@ class Spider(Pangu):
         if queue_name is ...:
             queue_name = self.queue_name
         seeds = seeds or {}
-        task_queue.continue_(queue_name, maxsize=maxsize, interval=1)
-        return task_queue.put(
-            queue_name, *pandora.iterable(seeds), priority=priority, **kwargs
+        task_queue.continue_(queue_name, maxsize=maxsize, interval=1)  # type: ignore
+        return task_queue.put(  # type: ignore
+            queue_name,  # type: ignore
+            *pandora.iterable(seeds),
+            priority=priority,
+            **kwargs,  # type: ignore
         )
 
     def _when_put_seeds(self, raw_method):  # noqa
         @functools.wraps(raw_method)
         def wrapper(
-            seeds: Union[dict, Item, List[Item], List[dict]],
-            task_queue: Optional[TaskQueue] = ...,
-            queue_name: Optional[str] = ...,
-            maxsize: Optional[int] = None,
-            priority: Optional[bool] = False,
-            **kwargs,
+                seeds: Union[dict, Item, List[Item], List[dict]],
+                task_queue: Optional[TaskQueue] = ...,
+                queue_name: Optional[str] = ...,
+                maxsize: Optional[int] = None,
+                priority: Optional[bool] = False,
+                **kwargs,
         ):
             where = kwargs.pop("where", None)
             if where == "init":
-                context: InitContext = InitContext.get_context()
+                context: InitContext = InitContext.get_context()  # type: ignore
                 context.form = state.const.BEFORE_PUT_SEEDS
                 events.EventManager.invoke(context)
                 args = [context.seeds]
@@ -472,7 +496,7 @@ class Spider(Pangu):
             ret = prepared.func(*prepared.args, **prepared.kwargs)
 
             if where == "init":
-                context: InitContext = InitContext.get_context()
+                context: InitContext = InitContext.get_context()  # type: ignore
                 context.form = state.const.AFTER_PUT_SEEDS
                 events.EventManager.invoke(context)
             else:
@@ -489,14 +513,12 @@ class Spider(Pangu):
 
         :return:
         """
-        task_queue: TaskQueue = self.get("spider.task_queue", self.task_queue)
-        queue_name: str = self.get("spider.queue_name", self.queue_name)
+        task_queue: TaskQueue = self.get("spider.task_queue", self.task_queue)  # type: ignore
+        queue_name: str = self.get("spider.queue_name", self.queue_name)  # type: ignore
         output = time.time()
 
         while True:
-            context: Context = self.make_context(
-                task_queue=task_queue, queue_name=queue_name
-            )
+            context: Context = self.make_context(task_queue=task_queue, queue_name=queue_name)  # type: ignore
             with context:
                 prepared = pandora.prepare(
                     func=self.get_seeds,
@@ -534,15 +556,15 @@ class Spider(Pangu):
                     # 判断是否应该停止爬虫
                     #  没有初始化 + 本地没有运行的任务 + 任务队列为空 -> 退出
                     if (
-                        not task_queue.command(
-                            queue_name, {"action": task_queue.COMMANDS.IS_INIT}
-                        )
-                        and not self.forever
-                        and self.dispatcher.running == 0
-                        and task_queue.is_empty(
-                            queue_name,
-                            threshold=self.get("spider.threshold", default=0),
-                        )
+                            not task_queue.command(
+                                queue_name, {"action": task_queue.COMMANDS.IS_INIT}
+                            )
+                            and not self.forever
+                            and self.dispatcher.running == 0
+                            and task_queue.is_empty(
+                        queue_name,
+                        threshold=self.get("spider.threshold", default=0),
+                    )
                     ):
                         number_of_seeds_obtained = self.number_of_seeds_obtained.value
                         number_of_new_seeds = self.number_of_new_seeds.value
@@ -551,7 +573,7 @@ class Spider(Pangu):
                             self.number_of_failure_requests.value
                         )
                         number_of_success_requests = (
-                            number_of_total_requests - number_of_failure_requests
+                                number_of_total_requests - number_of_failure_requests
                         )
                         if number_of_total_requests:
                             rate_of_success_requests = round(
@@ -584,7 +606,7 @@ class Spider(Pangu):
 
                     else:
                         if task_queue.smart_reverse(
-                            queue_name, status=self.dispatcher.running
+                                queue_name, status=self.dispatcher.running
                         ):
                             logger.debug(f"[翻转队列] 队列名称: {queue_name}")
 
@@ -616,15 +638,15 @@ class Spider(Pangu):
         @functools.wraps(raw_method)
         def wrapper(*args, **kwargs):
             with self.dispatcher:
-                task_queue: TaskQueue = self.get("spider.task_queue", self.task_queue)
-                queue_name: str = self.get("spider.queue_name", self.queue_name)
+                task_queue: TaskQueue = self.get("spider.task_queue", self.task_queue)  # type: ignore
+                queue_name: str = self.get("spider.queue_name", self.queue_name)  # type: ignore
                 server = task_queue.command(
                     queue_name,
                     {
                         "action": task_queue.COMMANDS.RUN_SUBSCRIBE,
                         "target": {
                             "collect-status": lambda: self.dispatcher.running
-                            + self.number_of_seeds_pending
+                                                      + self.number_of_seeds_pending
                         },
                     },
                 )
@@ -632,7 +654,7 @@ class Spider(Pangu):
                 try:
                     return raw_method(*args, **kwargs)
                 finally:
-                    hasattr(server, "stop") and server.stop()
+                    hasattr(server, "stop") and server.stop()  # type: ignore
 
         return wrapper
 
@@ -640,8 +662,8 @@ class Spider(Pangu):
         with self.dispatcher:
             t1 = int(time.time() * 1000)
             future = self.active(dispatch.Task(func=self.run_init))
-            task_queue: TaskQueue = self.get("init.task_queue", self.task_queue)
-            queue_name: str = self.get("init.queue_name", self.queue_name)
+            task_queue: TaskQueue = self.get("init.task_queue", self.task_queue)  # type: ignore
+            queue_name: str = self.get("init.queue_name", self.queue_name)  # type: ignore # type: ignore
             task_queue.command(
                 queue_name, {"action": task_queue.COMMANDS.WAIT_INIT, "time": t1}
             )
@@ -654,7 +676,7 @@ class Spider(Pangu):
 
         :return:
         """
-        context: Context = Context.get_context()
+        context: Context = Context.get_context()  # type: ignore
         task_queue: TaskQueue = kwargs.pop("task_queue", None) or context.task_queue
         queue_name: str = kwargs.pop("queue_name", None) or context.queue_name
         return task_queue.get(name=queue_name, **kwargs)
@@ -662,7 +684,7 @@ class Spider(Pangu):
     def _when_get_seeds(self, raw_method):
         @functools.wraps(raw_method)
         def wrapper(**kwargs):
-            context: Context = Context.get_context()
+            context: Context = Context.get_context()  # type: ignore
             context.form = state.const.BEFORE_GET_SEEDS
             events.EventManager.invoke(context)
             count = self.dispatcher.max_workers - self.dispatcher.running
@@ -695,7 +717,7 @@ class Spider(Pangu):
                 ctx = context
             else:
                 ctx = context.branch()
-                ctx.division and ctx.divisive()
+                ctx.division and ctx.divisive()  # type: ignore
 
             ctx.flow({"request": stuff})
 
@@ -710,8 +732,10 @@ class Spider(Pangu):
         response: Response = context.response
         error: str = response.error if response else ""
         del context.response
-        context.response = None
-        if request.retry < request.max_retry:
+        context.response = None  # type: ignore
+
+        max_retry = request.get_options("$maxRetry", math.inf)
+        if request.retry < min(max_retry, request.max_retry):
             # 如果是代理错误, 则不计算重试次数
             if not IGNORE_RETRY_PATTERN.search(error):
                 request.retry += 1
@@ -729,7 +753,7 @@ class Spider(Pangu):
             msg = f'[超过重试次数] {f"SEEDS: {context.seeds}, " if context.seeds else ""} URL: {request.real_url}'
             logger.warning(msg)
 
-            if request.retry >= request.get_options("$maxRetry", math.inf):
+            if request.retry >= max_retry:
                 raise signals.Success
 
             else:
@@ -746,7 +770,7 @@ class Spider(Pangu):
                 args=args,
                 kwargs=kwargs,
                 annotations={
-                    self.Context: context,
+                    type(context): context,
                     Response: context.response,
                     Item: context.seeds,
                 },
@@ -778,7 +802,7 @@ class Spider(Pangu):
             )
             response: Response = future.result()
         else:
-            response: Response = downloader.fetch(context.request)
+            response: Response = downloader.fetch(context.request)  # noqa
 
         return response
 
@@ -790,7 +814,7 @@ class Spider(Pangu):
                 events.EventManager.invoke(
                     context,
                     annotations={
-                        self.Context: context,
+                        type(context): context,
                         Item: context.seeds,
                         Request: context.request,
                     },
@@ -806,6 +830,9 @@ class Spider(Pangu):
                 else:
                     gen = context.response
 
+            except signals.Skip:
+                gen = context.response
+
             else:
                 context.form = state.const.ON_REQUEST
                 self.number_of_total_requests.increment()
@@ -814,7 +841,7 @@ class Spider(Pangu):
                     args=args,
                     kwargs=kwargs,
                     annotations={
-                        self.Context: context,
+                        type(context): context,
                         Item: context.seeds,
                         Request: context.request,
                     },
@@ -832,7 +859,7 @@ class Spider(Pangu):
                     ctx = context
                 else:
                     ctx = context.branch()
-                    ctx.division and ctx.divisive()
+                    ctx.division and ctx.divisive()  # type: ignore
 
                 ctx.flow(
                     {"response": stuff, "request": stuff.request},
@@ -842,7 +869,7 @@ class Spider(Pangu):
                     ctx,
                     form=state.const.AFTER_REQUEST,
                     annotations={
-                        self.Context: ctx,
+                        type(ctx): ctx,
                         Item: ctx.seeds,
                         Request: ctx.request,
                         Response: ctx.response,
@@ -925,7 +952,7 @@ class Spider(Pangu):
                     ctx = context
                 else:
                     ctx = context.branch()
-                    ctx.division and ctx.divisive()
+                    ctx.division and ctx.divisive()  # type: ignore
 
                 ctx.flow({"items": stuff}, flag=ctx.next == self.on_response)
 
@@ -973,44 +1000,50 @@ class Spider(Pangu):
         @functools.wraps(raw_method)
         def wrapper(context: Context, *args, **kwargs):
             context.form = state.const.BEFORE_PIPELINE
-            events.EventManager.invoke(
-                context,
-                annotations={
-                    Response: context.response,
-                    Request: context.request,
-                    Items: context.items,
-                    Item: context.seeds,
-                    Context: context,
-                },
-                namespace={
-                    "context": context,
-                    "request": context.request,
-                    "response": context.response,
-                    "seeds": context.seeds,
-                    "items": context.items,
-                },
-            )
-            context.form = state.const.ON_PIPELINE
-            prepared = pandora.prepare(
-                func=raw_method,
-                args=args,
-                kwargs=kwargs,
-                annotations={
-                    Response: context.response,
-                    Request: context.request,
-                    Items: context.items,
-                    Item: context.seeds,
-                    Context: context,
-                },
-                namespace={
-                    "context": context,
-                    "request": context.request,
-                    "response": context.response,
-                    "seeds": context.seeds,
-                    "items": context.items,
-                },
-            )
-            prepared.func(*prepared.args, **prepared.kwargs)
+            try:
+                events.EventManager.invoke(
+                    context,
+                    annotations={
+                        Response: context.response,
+                        Request: context.request,
+                        Items: context.items,
+                        Item: context.seeds,
+                        Context: context,
+                    },
+                    namespace={
+                        "context": context,
+                        "request": context.request,
+                        "response": context.response,
+                        "seeds": context.seeds,
+                        "items": context.items,
+                    },
+                )
+            except signals.Skip:
+                pass
+
+            else:
+                context.form = state.const.ON_PIPELINE
+                prepared = pandora.prepare(
+                    func=raw_method,
+                    args=args,
+                    kwargs=kwargs,
+                    annotations={
+                        Response: context.response,
+                        Request: context.request,
+                        Items: context.items,
+                        Item: context.seeds,
+                        Context: context,
+                    },
+                    namespace={
+                        "context": context,
+                        "request": context.request,
+                        "response": context.response,
+                        "seeds": context.seeds,
+                        "items": context.items,
+                    },
+                )
+                prepared.func(*prepared.args, **prepared.kwargs)
+
             context.form = state.const.AFTER_PIPELINE
             events.EventManager.invoke(
                 context,
@@ -1029,6 +1062,7 @@ class Spider(Pangu):
                     "items": context.items,
                 },
             )
+
             context.flow(flag=context.next == self.on_pipeline)
 
         return wrapper
@@ -1037,7 +1071,7 @@ class Spider(Pangu):
         raise NotImplementedError
 
     def make_request(self, context: Context) -> Request:
-        return pandora.invoke(Request, kwargs=context.seeds)
+        return pandora.invoke(Request, kwargs=context.seeds)  # type: ignore
 
     def _when_make_request(self, raw_method):  # noqa
         @functools.wraps(raw_method)
@@ -1061,17 +1095,13 @@ class Spider(Pangu):
                 },
             )
             future_max_retry = context.seeds.get("$futureMaxRetry")
-            future_retry = context.seeds.get("$futureRetry") or 0
+            future_retry: int = context.seeds.get("$futureRetry") or 0  # type: ignore
             request = prepared.func(*prepared.args, **prepared.kwargs)
-
-            context.seeds["$futureRetry"] = request.retry
-
             if future_max_retry:
                 request.max_retry = future_max_retry
                 request.put_options("$maxRetry", future_max_retry)
-
-            if future_retry:
                 request.retry = future_retry + 1
+                context.seeds["$futureRetry"] = request.retry
 
             context.form = state.const.AFTER_MAKE_REQUEST
             events.EventManager.invoke(
@@ -1102,7 +1132,7 @@ class Spider(Pangu):
         )
 
     def item_pipeline(self, context: Context):
-        context.items and logger.debug(context.items)
+        context.items and logger.debug(context.items)  # type: ignore
         context.success()
 
     def install(self):
@@ -1121,11 +1151,11 @@ class Spider(Pangu):
 
     @pandora.Method
     def survey(
-        binding,  # noqa
-        *seeds: dict,
-        attrs: dict = None,
-        modded: dict = None,
-        extract: list = None,
+            binding,  # noqa
+            *seeds: dict,
+            attrs: dict = None,  # type: ignore
+            modded: dict = None,  # type: ignore
+            extract: list = None,  # type: ignore
     ) -> List[Context]:
         """
         调查种子, collect 会收集产生的 Context
@@ -1175,19 +1205,19 @@ class Spider(Pangu):
         REGISTERED_EVENTS.lazy_loading[f"{clazz.__module__}.{clazz.__name__}"] = (
             REGISTERED_EVENTS.lazy_loading[key].copy()
         )
-        survey: Spider = clazz(**attrs)
+        survey: Spider = clazz(**attrs)  # type: ignore
         survey.run()
         return (
             list(collect.queue)
             if not extract
             else [{k: getattr(c, k) for k in extract} for c in collect.queue]
-        )
+        )  # type: ignore
 
     def create_fetcher(
-        self,
-        downloader: Optional[AbstractDownloader] = None,
-        plugins: Union[dict, None] = ...,
-        **options,
+            self,
+            downloader: Optional[AbstractDownloader] = None,
+            plugins: Union[dict, None] = ...,
+            **options,
     ):
         key = json.dumps(
             {"downloader": id(downloader), "plugins": plugins, **options},
@@ -1224,12 +1254,12 @@ class Spider(Pangu):
         return _fetchers_cache[key]
 
     def fetch(
-        self,
-        request: Union[Request, dict],
-        downloader: Optional[AbstractDownloader] = None,
-        proxy: Optional[Union[dict, BaseProxy]] = ...,
-        plugins: Union[dict, None] = ...,
-        **options,
+            self,
+            request: Union[Request, dict],
+            downloader: Optional[AbstractDownloader] = None,
+            proxy: Optional[Union[dict, BaseProxy]] = ...,
+            plugins: Union[dict, None] = ...,
+            **options,
     ) -> Response:
         """
         发送请求获取响应
@@ -1254,7 +1284,7 @@ class Spider(Pangu):
             if proxy is ...:
                 request.proxy = self.proxy
             elif proxy:
-                request.proxy = proxy
+                request.proxy = proxy  # type: ignore
             else:
                 pass
 
@@ -1278,4 +1308,4 @@ class Spider(Pangu):
             "number_of_seeds_obtained",
         ]
         for count_name in counters:
-            self.get(count_name).disable()
+            self.get(count_name).disable()  # type: ignore
